@@ -432,8 +432,9 @@ class _ActionItem(object):
       """
         fields = splitCommandLine(hook.command)
         logger.debug("Executing %s hook for action [%s]: %s", type, hook.action, fields[0:1])
-        result = executeCommand(command=fields[0:1], args=fields[1:])[0]
+        result, output = executeCommand(command=fields[0:1], args=fields[1:], returnOutput=True)
         if result != 0:
+            logger.debug("Hook failed, tail is: %s", "\n   %s" % "   ".join(output[-10:]) if output else "<empty>")
             raise IOError("Error (%d) executing %s hook for action [%s]: %s" % (result, type, hook.action, fields[0:1]))
 
 
