@@ -34,7 +34,7 @@ Attributes:
 
 AUTHOR = "Kenneth J. Pronovici"
 EMAIL = "pronovic@ieee.org"
-COPYRIGHT = "2004-2020"
-VERSION = "3.5.1"
-DATE = "30 Dec 2020"
+COPYRIGHT = "2004-2021"
+VERSION = "3.5.2"
+DATE = "14 Jan 2021"
 URL = "https://github.com/pronovic/cedar-backup3"
