@@ -45,13 +45,11 @@ Provides utilities related to image writers.
 # Imported modules
 ########################################################################
 
+import logging
 import os
 import re
-import logging
-
-from CedarBackup3.util import resolveCommand, executeCommand
-from CedarBackup3.util import convertSize, UNIT_BYTES, UNIT_SECTORS, encodePath
 
+from CedarBackup3.util import UNIT_BYTES, UNIT_SECTORS, convertSize, encodePath, executeCommand, resolveCommand
 
 ########################################################################
 # Module-wide constants and variables
@@ -119,7 +117,7 @@ def validateScsiId(scsiId):
     if scsiId is not None:
         pattern = re.compile(r"^\s*(.*:)?\s*[0-9][0-9]*\s*,\s*[0-9][0-9]*\s*,\s*[0-9][0-9]*\s*$")
         if not pattern.search(scsiId):
-            pattern = re.compile(r"^\s*IO.*Services(\/[0-9][0-9]*)?\s*$")
+            pattern = re.compile(r"^\s*IO.*Services(/[0-9][0-9]*)?\s*$")
             if not pattern.search(scsiId):
                 raise ValueError("SCSI id is not in a valid form.")
     return scsiId
